@@ -151,7 +151,7 @@ class TestHudComputerToolExtended:
     async def test_type_action(self, base_executor):
         """Test type action with BaseExecutor."""
         tool = HudComputerTool(executor=base_executor)
-        result = await tool(action="type", text="Hello World", enter_after=True)
+        result = await tool(action="write", text="Hello World", enter_after=True)
         assert result
         assert any(
             "[SIMULATED] Type" in content.text
@@ -272,14 +272,6 @@ class TestHudComputerToolExtended:
         result = await tool(action="click", x=100, y=100, pattern=[100])
         assert result
 
-    @pytest.mark.asyncio
-    async def test_invalid_action(self, base_executor):
-        """Test invalid action returns error."""
-        tool = HudComputerTool(executor=base_executor)
-
-        with pytest.raises(Exception):  # Will raise McpError
-            await tool(action="invalid_action")
-
     @pytest.mark.asyncio
     async def test_screenshot_action(self, base_executor):
         """Test screenshot action."""
@@ -329,7 +321,7 @@ class TestHudComputerToolExtended:
         assert result
 
         # Test type without coordinates
-        result = await tool(action="type", text="test")
+        result = await tool(action="write", text="test")
         assert result
 
     @pytest.mark.asyncio
@@ -360,7 +352,7 @@ class TestHudComputerToolExtended:
         from hud.tools.types import ToolError
 
         with pytest.raises(ToolError, match="text parameter is required"):
-            await tool(action="type", text=None)
+            await tool(action="write", text=None)
 
         # Test press without keys
         with pytest.raises(ToolError, match="keys parameter is required"):
